package com.ventas.database;

import java.text.NumberFormat;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class ArtibarDBAdapter {
	public static final String CODIGOBARRAS = "_id"; 
    public static final String CODIARTI = "codiarti"; 
    public static final String CANTSTVT = "cantstvt"; 
    public static final String CODIUNID = "codiunid"; 

    public static final String DATABASE_TABLE = "artibar"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public ArtibarDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
 
    /** 
     * Create a new artibar. If the artibar is successfully created return the new 
     * rowId for that artibar, otherwise return a -1 to indicate failure. 
     *  
     * @param codigobarras 
     * @param codiarti 
     * @param cantstvt 
     * @param codiunid 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codigobarras, String codiarti, double cantstvt, String codiunid){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIGOBARRAS, codigobarras); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(CANTSTVT, cantstvt); 
        initialValues.put(CODIUNID, codiunid); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the artibar with the given rowId 
     *  
     * @param codigobarras 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codigobarras) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIGOBARRAS + "= '" + codigobarras + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all artibars in the database 
     *  
     * @return Cursor over all artibars 
     */ 
    public Cursor getAll() { 
 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODIGOBARRAS, 
        		CODIARTI, CODIUNID, CANTSTVT }, null, null, null, null, null); 
    } 
 
    /** 
     * Return a Cursor positioned at the artibar that matches the given rowId 
     * @param codigobarras 
     * @return Cursor positioned to matching artibar, if found 
     * @throws SQLException if artibar could not be found/retrieved 
     */ 
    public Cursor get(String codigobarras) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIGOBARRAS, 
        		CODIARTI, CODIUNID, CANTSTVT }, CODIGOBARRAS + "= '" + codigobarras + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Return a Cursor positioned at the artibar that matches the given codiarti
     * @param codiarti 
     * @return Cursor positioned to matching artibar, if found 
     * @throws SQLException if artibar could not be found/retrieved 
     */ 
    public Cursor getByCodiarti(String codiarti) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIGOBARRAS, 
        		CODIARTI, CODIUNID, CANTSTVT }, CODIARTI + "= '" + codiarti + "'", null, null, null, CANTSTVT, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the artibar. 
     *  
     * @param codigobarras 
     * @param codiarti 
     * @param cantstvt 
     * @param codiunid 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codigobarras, String codiarti, double cantstvt, String codiunid){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIGOBARRAS, codigobarras); 
        args.put(CODIARTI, codiarti); 
        args.put(CODIUNID, codiunid); 
        args.put(CANTSTVT, cantstvt); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODIGOBARRAS + "= '" + codigobarras + "'", null) >0;  
    } 

    /** 
     * Create a new artibar from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf     = NumberFormat.getInstance();
    	String codigobarras = linea[1];
    	String codiarti     = linea[2];
    	double cantstvt     = 0;
    	String codiunid      = linea[4];
    	
    	try{
    		cantstvt = nf.parse(linea[3]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	return create(codigobarras, codiarti, cantstvt, codiunid);
    }

    /** 
     * Update an artibar from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	NumberFormat nf = NumberFormat.getInstance();
    	ContentValues args = new ContentValues(); 
    	double valor = 0;
    	
    	String codigobarras = linea[1];
    	args.put(CODIGOBARRAS, codigobarras); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		
    		if ( linea[i].equalsIgnoreCase(CANTSTVT) ) { //es campo DOUBLE
    			try{
    				valor = nf.parse( linea[i+1] ).doubleValue();
    			}catch(Exception e){
    	       	}
    			args.put(linea[i], valor); 
    		}
    		else { //es campo string
    			args.put(linea[i], linea[i+1]); 
    		}
    		
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIGOBARRAS + "='" + codigobarras + "'", null) >0;  
    	
    }

    /** 
     * Delete artibar from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
