package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class ClienteDBAdapter {
    public static final String DATABASE_TABLE = "cliente"; 

    public static final String CODICLIE = "_id"; 
    public static final String DESCRIPCION = "descripcion";
    public static final String TITULAR = "titular"; 
    public static final String CODIPROV = "codiprov";
    public static final String CODPOSTAL = "codpostal";
    public static final String POBLACION = "poblacion";
    public static final String DIRECCION = "direccion";
    public static final String TELEFONO1 = "telefono1";
    public static final String TELEFONO2 = "telefono2";

 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public ClienteDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
 
    /** 
     * Create a new cliente. If the cliente is successfully created return the new 
     * rowId for that cliente, otherwise return a -1 to indicate failure. 
     *  
     * @param codiclie 
     * @param descripcion 
     * @param titular 
     * @param codiprov 
     * @param codpostal 
     * @param poblacion 
     * @param direccion 
     * @param telefono1 
     * @param telefono2 
     * @return rowId or -1 if failed 
     */ 
    public long create(int codiclie, 
    		                  String descripcion, 
    		                  String titular, 
    		                  String codiprov, 
    		                  String codpostal, 
    		                  String poblacion, 
    		                  String direccion, 
    		                  String telefono1, 
    		                  String telefono2){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(DESCRIPCION, descripcion); 
        initialValues.put(TITULAR, titular); 
        initialValues.put(CODIPROV, codiprov); 
        initialValues.put(CODPOSTAL, codpostal); 
        initialValues.put(POBLACION, poblacion); 
        initialValues.put(DIRECCION, direccion); 
        initialValues.put(TELEFONO1, telefono1); 
        initialValues.put(TELEFONO2, telefono2); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the cliente with the given rowId 
     *  
     * @param codiclie 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codiclie) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICLIE + "=" + codiclie, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all clientes in the database 
     *  
     * @return Cursor over all clientes
     */ 
    public Cursor getAll() { 
    	return this.mDb.query(DATABASE_TABLE, new String[] { CODICLIE, 
        		DESCRIPCION, TITULAR, CODIPROV, CODPOSTAL, POBLACION,
        		DIRECCION, TELEFONO1, TELEFONO2 }, null, null, null, null, DESCRIPCION); 
    } 
 
    /** 
     * Return a Cursor over the list of all clientes in the database 
     *  
     * @return Cursor over all clientes
     */ 
    public Cursor getAllConditional(String where) throws SQLException {
    	//Si la condicin est vaca, consultar sin condicin ya que ser ms rpido.
    	if (where == null || where.equals("")) {
    		return this.getAll();
    	}

    	try{
    		//Si la condicin es de tipo entero, consultar sobre el cdigo de cliente
	    	try{
	    		return this.get(Integer.valueOf(where).intValue());
	    	}
	    	catch(NumberFormatException nfe){
	    		//Si hay una excepcin, se trata de una cadena de texto.
	    	}
	    	
	        //Si la condicin no es de tipo entero, consultar sobre la descripcion
	    	return this.mDb.query(DATABASE_TABLE, new String[] { CODICLIE, 
	        		DESCRIPCION, TITULAR, CODIPROV, CODPOSTAL, POBLACION,
	        		DIRECCION, TELEFONO1, TELEFONO2 }, DESCRIPCION + " like '%" + where+"%'", null, null, null, DESCRIPCION);
    	}
    	catch (SQLException e){
    		throw e;
    	}
    } 
 
    /** 
     * Return a Cursor positioned at the cliente that matches the given rowId 
     * @param codiclie 
     * @return Cursor positioned to matching cliente, if found 
     * @throws SQLException if cliente could not be found/retrieved 
     */ 
    public Cursor get(long codiclie) throws SQLException { 
 
        Cursor mCursor =  
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODICLIE, 
        		DESCRIPCION, TITULAR, CODIPROV, CODPOSTAL, POBLACION,
        		DIRECCION, TELEFONO1, TELEFONO2 }, CODICLIE + "=" + codiclie, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 


    /** 
     * Update the cliente. 
     *  
     * @param codiclie 
     * @param descripcion 
     * @param titular 
     * @param codiprov 
     * @param codpostal 
     * @param poblacion 
     * @param direccion 
     * @param telefono1 
     * @param telefono2 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codiclie, 
 					             String descripcion, 
					             String titular, 
					             String codiprov, 
					             String codpostal, 
					             String poblacion, 
					             String direccion, 
					             String telefono1, 
					             String telefono2){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICLIE, codiclie); 
        args.put(DESCRIPCION, descripcion); 
        args.put(TITULAR, titular); 
        args.put(CODIPROV, codiprov); 
        args.put(CODPOSTAL, codpostal); 
        args.put(POBLACION, poblacion); 
        args.put(DIRECCION, direccion); 
        args.put(TELEFONO1, telefono1); 
        args.put(TELEFONO2, telefono2); 

        return this.mDb.update(DATABASE_TABLE, args, CODICLIE + "=" + codiclie, null) >0;  
    } 
    
    /** 
     * Create a new cliente from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	int    codiclie    = Integer.valueOf(linea[1]).intValue();
        String descripcion = linea[2]; 
        String titular     = linea[3];
        String codiprov    = linea[4];
        String codpostal   = linea[5];
        String poblacion   = linea[6];
        String direccion   = linea[7];
        String telefono1   = linea[8];
        String telefono2   = linea[9];
        
    	return create(codiclie, descripcion, titular, codiprov, codpostal, poblacion, direccion, telefono1, telefono2);
    }

    /** 
     * Update a cliente from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
	
    	ContentValues args = new ContentValues(); 
    	 
    	Long    codiclie    = Long.valueOf(linea[1]);
    	args.put(CODICLIE, codiclie); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		args.put(linea[i], linea[i+1]); 
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODICLIE + "=" + codiclie , null) >0;  
    	
    }

    /** 
     * Delete cliente from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		int codiclie = Integer.valueOf(linea[i]).intValue();
    		delete(codiclie);
    	}
    }
}
