package com.ventas.database;

import java.text.NumberFormat;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FclespDBAdapter {
	public static final String CODICLES = "_id"; 
    public static final String CODICLIE = "codiclie";
    public static final String CODIARTI = "codiarti"; 
    public static final String DESDEFECHA = "desdefecha";
    public static final String PRECIO = "precio";
    public static final String COMISION = "comision";
    
    public static final String DATABASE_TABLE = "f_clesp"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FclespDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
 
    /** 
     * Create a new f_clesp. If the f_clesp is successfully created return the new 
     * rowId for that f_clesp, otherwise return a -1 to indicate failure. 
     *  
     * @param codicles 
     * @param codiclie 
     * @param codiarti 
     * @param desdefecha 
     * @param precio 
     * @param comision 
     * @return rowId or -1 if failed 
     */ 
    public long create(long codicles, 
    						  long codiclie, 
    		                  String codiarti, 
    		                  String desdefecha, 
    		                  double precio, 
    		                  double comision){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICLES, codicles); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(DESDEFECHA, desdefecha); 
        initialValues.put(PRECIO, precio); 
        initialValues.put(COMISION, comision); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the f_clesp with the given rowId 
     *  
     * @param codicles 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codicles) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICLES + "=" + codicles, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_clesps in the database 
     *  
     * @return Cursor over all f_clesps
     */ 
    public Cursor getAll() { 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODICLES, 
        		CODICLIE, CODIARTI, DESDEFECHA, PRECIO,
        		COMISION }, null, null, null, null, null); 
} 
 
    /** 
     * Return a Cursor positioned at the f_clesp that matches the given rowId 
     * @param codicles 
     * @return Cursor positioned to matching f_clesp, if found 
     * @throws SQLException if f_clesp could not be found/retrieved 
     */ 
    public Cursor get(long codicles) throws SQLException { 
 
        Cursor mCursor = this.mDb.query(true, DATABASE_TABLE, new String[] { CODICLES, 
        		CODICLIE, CODIARTI, DESDEFECHA, PRECIO,
        		COMISION }, CODICLES + "=" + codicles, null, null, null, null, null); 

        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    /** 
     * Return a Cursor positioned at the f_clesp that matches the given vigencia, cliente and articulo 
     * @param vigencia 
     * @param cliente 
     * @param articulo 
     * @return Cursor positioned to matching f_clesp, if found 
     * @throws SQLException if f_clesp could not be found/retrieved 
     */ 
    public Cursor get(String vigencia, long cliente, String articulo) throws SQLException { 
        Cursor mCursor = this.mDb.query(DATABASE_TABLE, new String[] { CODICLES, 
        		CODICLIE, CODIARTI, DESDEFECHA, PRECIO,
        		COMISION }, CODICLIE + "=" + cliente + 
        		  " AND " + CODIARTI + "= '" + articulo + "'" + 
        		  " AND " + DESDEFECHA + "<= '" + vigencia + "'", null, null, null, DESDEFECHA + " DESC"); 

        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 


    /** 
     * Update the f_clesp. 
     *  
     * @param codicles 
     * @param codiclie 
     * @param codiarti 
     * @param desdefecha 
     * @param precio 
     * @param comision 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codicles, 
			  long codiclie, 
              String codiarti, 
              String desdefecha, 
              double precio, 
              double comision){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICLES, codicles); 
        args.put(CODICLIE, codiclie); 
        args.put(CODIARTI, codiarti); 
        args.put(DESDEFECHA, desdefecha); 
        args.put(PRECIO, precio); 
        args.put(COMISION, comision); 

        return this.mDb.update(DATABASE_TABLE, args, CODICLES + "=" + codicles, null) >0;  
    } 

    /** 
     * Create a new f_clesp from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf   = NumberFormat.getInstance();
    	long   codicles   = Long.valueOf(linea[1]).longValue(); 
		long   codiclie   = Long.valueOf(linea[2]).longValue(); 
        String codiarti   = linea[3]; 
        String desdefecha = linea[4]; 
        double precio     = 0; 
        double comision   = 0;
        
    	try{
    		precio = nf.parse(linea[5]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		comision = nf.parse(linea[6]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	return create(codicles, codiclie, codiarti, desdefecha, precio, comision);
    }


    /** 
     * Update a new f_clesp from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	NumberFormat nf = NumberFormat.getInstance();
    	ContentValues args = new ContentValues(); 
    	double valor = 0;
    	
    	Long codicles   = Long.valueOf(linea[1]); 
    	args.put(CODICLES, codicles); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		
    		if ( linea[i].equalsIgnoreCase(CODICLIE) ) { //es campo LONG
    			Long codiclie   = Long.valueOf( linea[i+1] ); 
    			args.put(linea[i], codiclie); 
    		}
    		else {
	    		if ( linea[i].equalsIgnoreCase(PRECIO) ||
	    			linea[i].equalsIgnoreCase(COMISION) ) { //es campo DOUBLE
	    			try{
	    				valor = nf.parse( linea[i+1] ).doubleValue();
	    			}catch(Exception e){
	    	       	}
	    			args.put(linea[i], valor); 
	    		}
	    		else { //es campo string
	    			args.put(linea[i], linea[i+1]); 
	    		}
    		}
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODICLES + "=" + codicles, null) >0;
    }

    /** 
     * Delete f_clesp from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		long codicles = Long.valueOf(linea[i]).longValue();
    		delete(codicles);
    	}
    }
}
