package com.ventas.database;


import java.text.NumberFormat;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class RiesclieDBAdapter {
	public static final String CODICLIE = "_id"; 
    public static final String FACTPEND = "factpend";
    public static final String CHEQPEND = "cheqpend"; 
    public static final String CHEQDEVU = "cheqdevu";
    public static final String CHEQRECO = "cheqreco";
    public static final String ALBAPEFA = "albapefa";
    public static final String RIESCONC = "riesconc";
    public static final String FECHACTU = "fechactu";
    
    public static final String DATABASE_TABLE = "riesclie"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public RiesclieDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
    /** 
     * Create a new riesclie. If the riesclie is successfully created return the new 
     * rowId for that riesclie, otherwise return a -1 to indicate failure. 
     *  
     * @param codiclie 
     * @param factpend 
     * @param cheqpend 
     * @param cheqdevu 
     * @param cheqreco 
     * @param albapefa 
     * @param riesconc 
     * @param fechactu 
     * @return rowId or -1 if failed 
     */ 
    public long create(int codiclie, 
							  double factpend, 
					          double cheqpend, 
				              double cheqdevu, 
				              double cheqreco, 
				              double albapefa, 
				              double riesconc, 
				              String fechactu){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(FACTPEND, factpend); 
        initialValues.put(CHEQPEND, cheqpend); 
        initialValues.put(CHEQDEVU, cheqdevu); 
        initialValues.put(CHEQRECO, cheqreco); 
        initialValues.put(ALBAPEFA, albapefa); 
        initialValues.put(RIESCONC, riesconc); 
        initialValues.put(FECHACTU, fechactu); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the riesclie with the given rowId 
     *  
     * @param codiclie 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(int codiclie) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICLIE + "=" + codiclie, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all riesclies in the database 
     *  
     * @return Cursor over all riesclies
     */ 
    public Cursor getAll() { 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODICLIE, 
        		FACTPEND, CHEQPEND, CHEQDEVU, CHEQRECO, ALBAPEFA,
        		RIESCONC, FECHACTU }, null, null, null, null, null); 
} 
 
    /** 
     * Return a Cursor positioned at the riesclie that matches the given rowId 
     * @param codiclie 
     * @return Cursor positioned to matching riesclie, if found 
     * @throws SQLException if riesclie could not be found/retrieved 
     */ 
    public Cursor get(int codiclie) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODICLIE, 
        		FACTPEND, CHEQPEND, CHEQDEVU, CHEQRECO, ALBAPEFA,
        		RIESCONC, FECHACTU }, CODICLIE + "=" + codiclie, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 


    /** 
     * Update the riesclie. 
     *  
     * @param codiclie 
     * @param factpend 
     * @param cheqpend 
     * @param cheqdevu 
     * @param cheqreco 
     * @param albapefa 
     * @param riesconc 
     * @param fechactu 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(int codiclie, 
						  double factpend, 
				          double cheqpend, 
			              double cheqdevu, 
			              double cheqreco, 
			              double albapefa, 
			              double riesconc, 
			              String fechactu){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICLIE, codiclie); 
        args.put(FACTPEND, factpend); 
        args.put(CHEQPEND, cheqpend); 
        args.put(CHEQDEVU, cheqdevu); 
        args.put(CHEQRECO, cheqreco); 
        args.put(ALBAPEFA, albapefa); 
        args.put(RIESCONC, riesconc); 
        args.put(FECHACTU, fechactu); 

        return this.mDb.update(DATABASE_TABLE, args, CODICLIE + "=" + codiclie, null) >0;  
    } 

    /** 
     * Create a new riesclie from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf = NumberFormat.getInstance();
    	int    codiclie = Integer.valueOf(linea[1]).intValue(); 
		double factpend = 0; 
        double cheqpend = 0; 
        double cheqdevu = 0;
        double cheqreco = 0;
        double albapefa = 0;
        double riesconc = 0;
        String fechactu = linea[8];
        
    	try{
    		factpend = nf.parse(linea[2]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		cheqpend = nf.parse(linea[3]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		cheqdevu = nf.parse(linea[4]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		cheqreco = nf.parse(linea[5]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		albapefa = nf.parse(linea[6]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		riesconc = nf.parse(linea[7]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	return create(codiclie, factpend, cheqpend, cheqdevu, cheqreco, albapefa, riesconc, fechactu);
    }

    /** 
     * Update a new riesclie from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	NumberFormat nf = NumberFormat.getInstance();
    	ContentValues args = new ContentValues(); 
    	double valor = 0;
    	
    	int    codiclie = Integer.valueOf(linea[1]).intValue();
    	args.put(CODICLIE, codiclie); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		
    		if ( linea[i].equalsIgnoreCase(FECHACTU) ) { //es campo String
    			args.put(linea[i], linea[i+1]); 
    		}
    		else { //es campo double
    			try{
    				valor = nf.parse( linea[i+1] ).doubleValue();
    			}catch(Exception e){
    	       	}
    			args.put(linea[i], valor); 
    		}
    		
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODICLIE + "=" + codiclie, null) >0;  
    }

    /** 
     * Delete riesclie from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		int codiclie = Integer.valueOf(linea[i]).intValue();
    		delete(codiclie);
    	}
    }
}
